console.log("✅ background.js 已成功加载");

chrome.action.onClicked.addListener((tab) => {
    chrome.tabs.update(tab.id, { url: "chrome-extension://" + chrome.runtime.id + "/index.html#/dashboard" });
});

// 获取 Cookies
function getCookies(domain, callback) {
    chrome.cookies.getAll({ domain: domain }, function (cookies) {
        let cookieString = cookies.map(c => `${c.name}=${c.value}`).join("; ");
        callback(cookieString);
    });
}

// 发送 API 请求
function fetchData_buff(callback) {
    let result = { buff: null};

    getCookies("buff.163.com", function (buffCookies) {
        fetch("https://buff.163.com/api/market/steam_inventory?game=csgo&page_size=1000", {
            headers: { "Cookie": buffCookies }
        })
        .then(response => response.json())
        .then(data => {
            result.buff = data;
            checkDone();
        })
        .catch(error => {
            console.error("BUFF 请求失败:", error);
            checkDone();
        });
    });
    function checkDone() {
        if (result.buff !== null) {
            callback(result);
        }
    }
}
function extractClassidPrice(data) {

    // 提取 classid
    let assets = data.assets?.["730"]?.["2"] || {};
    let classidList = Object.values(assets).map(item => item.classid);

    // 提取 price
    let resultsHtml = data.results_html || "";
    let priceMatches = resultsHtml.match(/market_listing_price">\s*\$([\d.]+)/g) || [];
    let priceList = priceMatches.map(match => match.match(/\$([\d.]+)/)[1]);

    // 组装成 {classid: price} 形式的对象
    let result = {};
    for (let i = 0; i < Math.min(classidList.length, priceList.length); i++) {
        result[classidList[i]] = priceList[i];
    }

    return result;
}
function fetchData_steam(callback) {
    let allAssets = {}; // 存储所有 assets
    let start = 0; // 分页起始位置
    let count = 200; // 每次请求的数量
    let totalCount = null; // 总数

    getCookies("steamcommunity.com", function (steamCookies) {
        function fetchPage() {
            fetch(`https://steamcommunity.com/market/myhistory/render/?start=${start}&count=${count}`, {
                headers: { "Cookie": steamCookies }
            })
            .then(response => response.json())
            .then(data => {
                // 确保成功响应且 results_html 存在
                if (data.success && data.results_html) {
                    // 初始化总条数
                    if (totalCount === null) {
                        totalCount = data.total_count;
                        console.log(`总共 ${totalCount} 条数据，开始获取...`);
                    }

                    // 检查 results_html 是否为空
                    if (!data.results_html.trim()) {
                        console.log("没有获取到有效的商品数据，检查返回的 HTML 是否正确。");
                        callback(allAssets); // 返回空数组
                        return;
                    }
                    let result = extractClassidPrice(data);
                    Object.assign(allAssets, result); // 合并到 allAssets


                    // 如果还有未获取的数据，继续请求
                    if (start + count < totalCount) {
                        start += count;
                        fetchPage(); // 递归请求下一页
                    } else {
                        console.log(`所有数据获取完毕，共 ${allAssets.length} 个 assets`);
                        callback(allAssets); // 一次性返回整个数组
                    }
                } else {
                    console.error("Steam API 返回错误或数据格式不正确:", data);
                    callback([]); // 失败时返回空数组
                }
            })
            .catch(error => {
                console.error("Steam 请求失败:", error);
                callback([]); // 失败时返回空数组
            });
        }

        fetchPage(); // 开始请求
    });
}


chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    console.log("background.js 收到消息:", request);

    if (request.action === "fetchData_buff") {
        console.log("✅ 执行 fetchData_buff 逻辑...");
        fetchData_buff((data) => {
            console.log("数据获取成功:", data);
            // 发送回给插件 `index.html`
            chrome.runtime.sendMessage({ type: "FETCH_DATA_RESPONSE", response: data });

            sendResponse(data);
        });
    }
    else if (request.action === "fetchData_steam") {
        console.log("✅ 执行 fetchData_steam 逻辑...");
        fetchData_steam((data) => {
            console.log("数据获取成功:", data);
            // 发送回给插件 `index.html`
            chrome.runtime.sendMessage({ type: "FETCH_DATA_STEAM_RESPONSE", response: data });

            sendResponse(data);
        });
    }

    return true; // 让 sendResponse() 异步可用
});
